@@ -88,6 +88,7 @@ setGeneric("proteins", function(object, ...) standardGeneric("proteins"))
 setGeneric("accessions", function(object, ...) standardGeneric("accessions"))
 setGeneric("tolerance", function(object, ...) standardGeneric("tolerance"))
 setGeneric("calculateFragments", function(sequence, object, ...) standardGeneric("calculateFragments"))
+setGeneric("adjacencyMatrix", function(object, ...) standardGeneric("adjacencyMatrix"))
 
 ## -------------------------------------------------------------
 ## Instrument
@@ -122,6 +123,8 @@ setGeneric("compareSpectra", function(x, y, ...)
     standardGeneric("compareSpectra"))
 setGeneric("compareChromatograms", function(x, y, ...)
     standardGeneric("compareChromatograms"))
+setGeneric("addProcessing", function(object, ...)
+    standardGeneric("addProcessing"))
 
 ## -------------------------------------------------------------
 ## IO
